Description Usage Arguments Value Examples
Title Send sequences to server
1 | sendToServer(df_sequences, email)
|
df_sequences |
data.frame with sequences (columns target and fasta required) |
email |
at the moment any email-like identifier, it is not checked |
object which you can use as input to retrieve results from server
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | email = "test11@test.com"
testseq <- data.frame(target = c("fasta_seq1", "fasta_seq2"),
fasta = c("RDPHPAPPRTSQEPHQNPHGVIPSESKPFVASKPKPHT",
"PSLPRPPGCPAQQGGSAPIDPPPVHESPHPPLPATEPASRLSSE"),
stringsAsFactors=FALSE)
# send sequences to server
sequences <- sendToServer(testseq, email)
# wait a couple of minutes, 1 sequence ~ 1-2 minutes of calculation
# retrive results from server ( only finished sequences )
structures <- getResultsFromServer(sequences)
# or you can obtain all finished sequences which associated with this email
all.structures <- getAllResultsFromServer(email)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.